@@ -10,7 +10,6 @@ for which a new license (GPL+exception) is in place.
 #include <QSqlError>
 
 #include "createviewdialog.h"
-#include "sqleditor.h"
 #include "database.h"
 
 
@@ -20,7 +19,6 @@ CreateViewDialog::CreateViewDialog(const QString & name, const QString & schema,
 {
 	ui.setupUi(this);
 	ui.databaseCombo->addItems(Database::getDatabases().keys());
-	new SqlEditorTools::SqlHighlighter(ui.sqlEdit->document());
 
 	ui.createButton->setDisabled(true);
 
@@ -40,13 +38,13 @@ void CreateViewDialog::createButton_clicked()
 	QString sql(QString("CREATE VIEW \"%1\".\"%2\" AS %3;")
 			.arg(ui.databaseCombo->currentText())
 			.arg(ui.nameEdit->text())
-			.arg(ui.sqlEdit->toPlainText()));
+			.arg(ui.sqlEdit->text()));
 
 	QSqlQuery query(sql, QSqlDatabase::database(SESSION_NAME));
 	
 	if(query.lastError().isValid())
 	{
-		ui.resultEdit->setText(tr("Error while creating view: %2.\n\n%3").arg(query.lastError().databaseText()).arg(sql));
+		ui.resultEdit->setText(tr("Error while creating view: %2.\n\n%3").arg(query.lastError().text()).arg(sql));
 		return;
 	}
 	ui.resultEdit->setText(tr("View created successfully"));
