@@ -12,8 +12,6 @@ for which a new license (GPL+exception) is in place.
 
 #include "ui_createviewdialog.h"
 
-class SqlHighlighter;
-
 
 /*! \brief GUI for view creation
 \author Petr Vanek <petr@scribus.info>
@@ -34,7 +32,6 @@ class CreateViewDialog : public QDialog
 
 	private:
 		Ui::CreateViewDialog ui;
-		SqlHighlighter * highlighter;
 
 		QString m_schema;
 		QString m_name;
