@@ -10,6 +10,7 @@ for which a new license (GPL+exception) is in place.
 
 #include "sqlmodels.h"
 #include "database.h"
+#include "preferences.h"
 
 
 SqlTableModel::SqlTableModel(QObject * parent, QSqlDatabase db)
@@ -18,12 +19,14 @@ SqlTableModel::SqlTableModel(QObject * parent, QSqlDatabase db)
 	m_schema("")
 {
 	m_deleteCache.clear();
-	m_useNull = PreferencesDialog::useNullHighlight();
-	m_nullColor = PreferencesDialog::nullHighlightColor();
-	m_nullText = PreferencesDialog::nullHighlightText();
-	m_useBlob = PreferencesDialog::useBlobHighlight();
-	m_blobColor = PreferencesDialog::blobHighlightColor();
-	m_blobText = PreferencesDialog::blobHighlightText();
+	Preferences * prefs = Preferences::instance();
+	m_useNull = prefs->nullHighlight();
+	m_nullColor = prefs->nullHighlightColor();
+	m_nullText = prefs->nullHighlightText();
+	m_useBlob = prefs->blobHighlight();
+	m_blobColor = prefs->blobHighlightColor();
+	m_blobText = prefs->blobHighlightText();
+	m_cropColumns = prefs->cropColumns();
 
 	connect(this, SIGNAL(primeInsert(int, QSqlRecord &)),
 			this, SLOT(doPrimeInsert(int, QSqlRecord &)));
@@ -32,10 +35,22 @@ SqlTableModel::SqlTableModel(QObject * parent, QSqlDatabase db)
 QVariant SqlTableModel::data(const QModelIndex & item, int role) const
 {
 	QString curr(QSqlTableModel::data(item, Qt::DisplayRole).toString());
+	// numbers
+	if (role == Qt::TextAlignmentRole)
+	{
+		bool ok;
+		curr.toDouble(&ok);
+		if (ok)
+			return QVariant(Qt::AlignRight | Qt::AlignTop);
+		return QVariant(Qt::AlignTop);
+	}
+
+	// mark rows prepared for a deletion in this trasnaction
+	if (role == Qt::BackgroundColorRole && m_deleteCache.contains(item.row()))
+		return QVariant(Qt::red);
 
 	// nulls
-	// FIXME: rewrite to the QSqlField::isNull?
-	if (m_useNull && (curr.isNull() || curr.isEmpty()))
+	if (m_useNull && curr.isNull())
 	{
 		if (role == Qt::BackgroundColorRole)
 			return QVariant(m_nullColor);
@@ -45,9 +60,13 @@ QVariant SqlTableModel::data(const QModelIndex & item, int role) const
 			return QVariant(m_nullText);
 	}
 	// BLOBs
+	// any others handling with blobs - e.g. converting to images etc.
+	// are followed with serious perfromance issues.
+	// Users can see it through edit dialog.
 	if (/*f.type.toUpper() == "BLOB" || */
-		m_useBlob &&
-		record().field(item.column()).type() == QVariant::ByteArray)
+		m_useBlob /*&&
+		   record().field(item.column()).type() == QVariant::ByteArray*/
+		   && QSqlTableModel::data(item, Qt::DisplayRole).type() == QVariant::ByteArray)
 	{
 		if (role == Qt::BackgroundColorRole)
 			return QVariant(m_blobColor);
@@ -56,15 +75,17 @@ QVariant SqlTableModel::data(const QModelIndex & item, int role) const
 		if (role == Qt::DisplayRole)
 			return QVariant(m_blobText);
 		if (role == Qt::EditRole)
-			return Database::hex(QSqlTableModel::data(item, Qt::DisplayRole).toByteArray());
+// 			return Database::hex(QSqlTableModel::data(item, Qt::DisplayRole).toByteArray());
+			return QSqlTableModel::data(item, Qt::DisplayRole);
 	}
-	// mark rows prepared for a deletion in this trasnaction
-	if (role == Qt::BackgroundColorRole && m_deleteCache.contains(item.row()))
-		return QVariant(Qt::red);
 
 	// advanced tooltips
 	if (role == Qt::ToolTipRole)
-		return QVariant(curr.length() > 6 ? curr.left(6)+"..." : "");
+		return QVariant("<qt>" + curr + "</qt>");
+
+	if (role == Qt::DisplayRole && m_cropColumns)
+		return QVariant(curr.length() > 20 ? curr.left(20)+"..." : curr);
+
 	return QSqlTableModel::data(item, role);
 }
 
@@ -114,7 +135,9 @@ bool SqlTableModel::removeRows ( int row, int count, const QModelIndex & parent)
 	bool ret = QSqlTableModel::removeRows(row, count, parent);
 	emit dataChanged( index(row, 0), index(row+count-1, columnCount()-1) );
 	emit headerDataChanged(Qt::Vertical, row, row+count-1);
-	m_deleteCache.append(row);
+	for (int i = 0; i < count; ++i)
+		m_deleteCache.append(row+i);
+
 	return ret;
 }
 
@@ -126,7 +149,7 @@ void SqlTableModel::setPendingTransaction(bool pending)
 	// If there is one...
 	if (!pending)
 	{
-		 for (int i = 0; i < m_deleteCache.size(); ++i)
+		for (int i = 0; i < m_deleteCache.size(); ++i)
 			emit headerDataChanged(Qt::Vertical, m_deleteCache[i], m_deleteCache[i]);
 	}
 	m_deleteCache.clear();
@@ -138,19 +161,31 @@ void SqlTableModel::setPendingTransaction(bool pending)
 SqlQueryModel::SqlQueryModel( QObject * parent)
 	: QSqlQueryModel(parent)
 {
-	m_useNull = PreferencesDialog::useNullHighlight();
-	m_nullColor = PreferencesDialog::nullHighlightColor();
-	m_nullText = PreferencesDialog::nullHighlightText();
-	m_useBlob = PreferencesDialog::useBlobHighlight();
-	m_blobColor = PreferencesDialog::blobHighlightColor();
-	m_blobText = PreferencesDialog::blobHighlightText();
+	Preferences * prefs = Preferences::instance();
+	m_useNull = prefs->nullHighlight();
+	m_nullColor = prefs->nullHighlightColor();
+	m_nullText = prefs->nullHighlightText();
+	m_useBlob = prefs->blobHighlight();
+	m_blobColor = prefs->blobHighlightColor();
+	m_blobText = prefs->blobHighlightText();
+	m_cropColumns = prefs->cropColumns();
 }
 
 QVariant SqlQueryModel::data(const QModelIndex & item, int role) const
 {
 	QString curr(QSqlQueryModel::data(item, Qt::DisplayRole).toString());
 
-	if (m_useNull && (curr.isNull() || curr.isEmpty()))
+	// numbers
+	if (role == Qt::TextAlignmentRole)
+	{
+		bool ok;
+		curr.toDouble(&ok);
+		if (ok)
+			return QVariant(Qt::AlignRight | Qt::AlignTop);
+		return QVariant(Qt::AlignTop);
+	}
+
+	if (m_useNull && curr.isNull())
 	{
 		if (role == Qt::BackgroundColorRole)
 			return QVariant(m_nullColor);
@@ -160,7 +195,10 @@ QVariant SqlQueryModel::data(const QModelIndex & item, int role) const
 			return QVariant(m_nullText);
 	}
 
-	if (m_useBlob && info.field(item.column()).type() == QVariant::ByteArray)
+	if (/*f.type.toUpper() == "BLOB" || */
+		m_useBlob /*&&
+		   record().field(item.column()).type() == QVariant::ByteArray*/
+		   && QSqlQueryModel::data(item, Qt::DisplayRole).type() == QVariant::ByteArray)
 	{
 		if (role == Qt::BackgroundColorRole)
 			return QVariant(m_blobColor);
@@ -169,8 +207,14 @@ QVariant SqlQueryModel::data(const QModelIndex & item, int role) const
 		if (role == Qt::DisplayRole)
 			return QVariant(m_blobText);
 	}
+
+	// advanced tooltips
 	if (role == Qt::ToolTipRole)
-		return QVariant(curr.length() > 6 ? curr.left(6)+"..." : "");
+		return QVariant("<qt>" + curr + "</qt>");
+
+	if (role == Qt::DisplayRole && m_cropColumns)
+		return QVariant(curr.length() > 20 ? curr.left(20)+"..." : curr);
+
 	return QSqlQueryModel::data(item, role);
 }
 
