@@ -11,8 +11,6 @@ for which a new license (GPL+exception) is in place.
 #include <QItemDelegate>
 #include <QSqlRecord>
 
-#include "preferencesdialog.h"
-
 class QPushButton;
 class QByteArray;
 
@@ -25,7 +23,10 @@ class SqlTableModel : public QSqlTableModel
 	public:
 		SqlTableModel( QObject * parent = 0, QSqlDatabase db = QSqlDatabase() );
 		~SqlTableModel() {};
+
 		void setSchema(const QString & schema) { m_schema = schema; };
+		QString schema() { return m_schema; };
+
 		bool pendingTransaction() { return m_pending; };
 
 		/*! \brief Set the pending flag \see m_pending to the transaction state
@@ -47,6 +48,7 @@ class SqlTableModel : public QSqlTableModel
 		bool m_pending;
 		QString m_schema;
 		QList<int> m_deleteCache;
+		bool m_cropColumns;
 
 		QVariant data(const QModelIndex & item, int role = Qt::DisplayRole) const;
 		bool setData(const QModelIndex & index, const QVariant & value, int role = Qt::EditRole);
@@ -76,6 +78,7 @@ class SqlQueryModel : public QSqlQueryModel
 		QColor m_blobColor;
 		QString m_blobText;
 		QSqlRecord info;
+		bool m_cropColumns;
 
 		QVariant data(const QModelIndex & item, int role = Qt::DisplayRole) const;
 };
