@@ -25,7 +25,7 @@ class TableEditorDialog : public QDialog
 		Q_OBJECT
 	public:
 		TableEditorDialog(QWidget * parent);
-		~TableEditorDialog(){};
+		~TableEditorDialog();
 
 		Ui::TableEditorDialog ui;
 
@@ -41,6 +41,8 @@ class TableEditorDialog : public QDialog
 		Else use default('foo') = add SQL string mark.
 		*/
 		QString getDefaultClause(const QString & defVal);
+		
+		QString getColumnClause(DatabaseTableField column);
 
 	public slots:
 		virtual void addField();
@@ -50,8 +52,6 @@ class TableEditorDialog : public QDialog
 		virtual void createButton_clicked();
 		virtual void tabWidget_currentChanged(int index);
 
-	private:
-		QComboBox * makeTypeBox();
 };
 
 #endif
