@@ -4,9 +4,12 @@ to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Sqliteman
 for which a new license (GPL+exception) is in place.
 */
+#include <QMouseEvent>
+#include <QApplication>
 
 #include "database.h"
 #include "tabletree.h"
+#include "utils.h"
 
 
 TableTree::TableTree(QWidget * parent) : QTreeWidget(parent)
@@ -18,12 +21,17 @@ TableTree::TableTree(QWidget * parent) : QTreeWidget(parent)
 	trViews = tr("Views");
 	trTriggers = tr("Triggers");
 	trSys = tr("System Catalogue");
+	trCols = tr("Columns");
 	
 	setColumnCount(2);
 	setHeaderLabels(QStringList() << trDatabase << "schema");
 	hideColumn(1);
 	
 	setContextMenuPolicy(Qt::CustomContextMenu);
+	setDragDropMode(QAbstractItemView::DragOnly);
+	setDragEnabled(true);
+	setDropIndicatorShown(true);
+	setAcceptDrops(false);
 }
 
 void TableTree::buildTree()
@@ -46,18 +54,18 @@ void TableTree::buildDatabase(QTreeWidgetItem * dbItem, const QString & schema)
 void TableTree::buildDatabase(const QString & schema)
 {
 	QTreeWidgetItem * dbItem = new QTreeWidgetItem(this, DatabaseItemType);
-	dbItem->setIcon(0, QIcon(QPixmap(QString(ICON_DIR) + "/database.png")));
+	dbItem->setIcon(0, Utils::getIcon("database.png"));
 	dbItem->setText(0, schema);
 	dbItem->setText(1, schema);
 
 	QTreeWidgetItem * tablesItem = new QTreeWidgetItem(dbItem, TablesItemType);
-	tablesItem->setIcon(0, QIcon(QPixmap(QString(ICON_DIR) + "/table.png")));
+	tablesItem->setIcon(0, Utils::getIcon("table.png"));
 
 	QTreeWidgetItem * viewsItem = new QTreeWidgetItem(dbItem, ViewsItemType);
-	viewsItem->setIcon(0, QIcon(QPixmap(QString(ICON_DIR) + "/view.png")));
+	viewsItem->setIcon(0, Utils::getIcon("view.png"));
 
 	QTreeWidgetItem * systemItem = new QTreeWidgetItem(dbItem, SystemItemType);
-	systemItem->setIcon(0, QIcon(QPixmap(QString(ICON_DIR) + "/system.png")));
+	systemItem->setIcon(0, Utils::getIcon("system.png"));
 
 	buildTables(tablesItem, schema);
 	buildViews(viewsItem, schema);
@@ -79,6 +87,9 @@ void TableTree::buildTables(QTreeWidgetItem * tablesItem, const QString & schema
 		QTreeWidgetItem * tableItem = new QTreeWidgetItem(tablesItem, TableType);
 		tableItem->setText(0, table);
 		tableItem->setText(1, schema);
+		// columns
+		QTreeWidgetItem *columnsItem = new QTreeWidgetItem(tableItem, ColumnItemType);
+		buildColumns(columnsItem, schema, table);
 		// indexes
 		QTreeWidgetItem *indexesItem = new QTreeWidgetItem(tableItem, IndexesItemType);
 		buildIndexes(indexesItem, schema, table);
@@ -96,7 +107,7 @@ void TableTree::buildIndexes(QTreeWidgetItem *indexesItem, const QString & schem
 	deleteChildren(indexesItem);
 	QStringList values = Database::getObjects("index", schema).values(table);
 	indexesItem->setText(0, trLabel(trIndexes).arg(values.size()));
-	indexesItem->setIcon(0, QIcon(QPixmap(QString(ICON_DIR) + "/index.png")));
+	indexesItem->setIcon(0, Utils::getIcon("index.png"));
 	indexesItem->setText(1, schema);
 	for (int i = 0; i < values.size(); ++i)
 	{
@@ -106,12 +117,27 @@ void TableTree::buildIndexes(QTreeWidgetItem *indexesItem, const QString & schem
 	}
 }
 
+void TableTree::buildColumns(QTreeWidgetItem * columnsItem, const QString & schema, const QString & table)
+{
+	deleteChildren(columnsItem);
+	FieldList values = Database::tableFields(table, schema);
+	columnsItem->setText(0, trLabel(trCols).arg(values.size()));
+	columnsItem->setIcon(0, Utils::getIcon("column.png"));
+// 	columnsItem->setText(1, schema);
+	for (int i = 0; i < values.size(); ++i)
+	{
+		QTreeWidgetItem *indexItem = new QTreeWidgetItem(columnsItem, ColumnType);
+		indexItem->setText(0, values.at(i).name);
+// 		indexItem->setText(1, schema);
+	}
+}
+
 void TableTree::buildSysIndexes(QTreeWidgetItem *indexesItem, const QString & schema, const QString & table)
 {
 	deleteChildren(indexesItem);
 	QStringList sysIx = Database::getSysIndexes(table, schema);
 	indexesItem->setText(0, trLabel(trSysIndexes).arg(sysIx.size()));
-	indexesItem->setIcon(0, QIcon(QPixmap(QString(ICON_DIR) + "/index.png")));
+	indexesItem->setIcon(0, Utils::getIcon("index.png"));
 	indexesItem->setText(1, schema);
 	for (int i = 0; i < sysIx.size(); ++i)
 	{
@@ -124,9 +150,9 @@ void TableTree::buildSysIndexes(QTreeWidgetItem *indexesItem, const QString & sc
 void TableTree::buildTriggers(QTreeWidgetItem *triggersItem, const QString & schema, const QString & table)
 {
 	deleteChildren(triggersItem);
-	QStringList values = Database::getObjects("trigger", schema).values(table);
+	QStringList values = Database::getObjects("trigger", schema).values(table.toLower());
 	triggersItem->setText(0, trLabel(trTriggers).arg(values.size()));
-	triggersItem->setIcon(0, QIcon(QPixmap(QString(ICON_DIR) + "/trigger.png")));
+	triggersItem->setIcon(0, Utils::getIcon("trigger.png"));
 	triggersItem->setText(1, schema);
 	for (int i = 0; i < values.size(); ++i)
 	{
@@ -149,6 +175,8 @@ void TableTree::buildViews(QTreeWidgetItem * viewsItem, const QString & schema)
 		QTreeWidgetItem * viewItem = new QTreeWidgetItem(viewsItem, ViewType);
 		viewItem->setText(0, view);
 		viewItem->setText(1, schema);
+		QTreeWidgetItem *triggersItem = new QTreeWidgetItem(viewItem, TriggersItemType);
+		buildTriggers(triggersItem, schema, view);
 	}
 }
 
@@ -195,3 +223,39 @@ void TableTree::buildViewTree(QString schema, QString name)
 			buildViews(item, schema);
 	}
 }
+
+void TableTree::mousePressEvent(QMouseEvent *event)
+{
+	if (event->button() == Qt::LeftButton)
+		m_dragStartPosition = event->pos();
+	QTreeWidget::mousePressEvent(event);
+}
+
+ void TableTree::mouseMoveEvent(QMouseEvent *event)
+{
+	if (!(event->buttons() & Qt::LeftButton))
+		return;
+	if ((event->pos() - m_dragStartPosition).manhattanLength()
+			< QApplication::startDragDistance())
+		return;
+
+	if (currentItem()->type() != TableTree::TableType &&
+		   currentItem()->type() != TableTree::ViewType &&
+		   currentItem()->type() != TableTree::DatabaseItemType &&
+		   currentItem()->type() != TableTree::IndexType &&
+		   currentItem()->type() != TableTree::TriggerType &&
+		   currentItem()->type() != TableTree::SystemType &&
+		   currentItem()->type() != TableTree::ColumnType)
+		return;
+
+#if QT_VERSION >= 0x040300
+	QDrag *drag = new QDrag(this);
+	QMimeData *mimeData = new QMimeData;
+
+	mimeData->setText(currentItem()->text(0));
+	drag->setMimeData(mimeData);
+	drag->exec(Qt::CopyAction);
+#endif
+
+	QTreeWidget::mouseMoveEvent(event);
+}
